withScale method
Convert to Decimal with specified scale and rounding mode
Implementation
@override
Decimal withScale(int scale, RoundingMode mode) {
return toDouble().toDecimal(scale: scale, mode: mode);
}
Convert to Decimal with specified scale and rounding mode
@override
Decimal withScale(int scale, RoundingMode mode) {
return toDouble().toDecimal(scale: scale, mode: mode);
}